/*
 * MIT License
 *
 * Copyright (c) 2019-present, iQIYI, Inc. All rights reserved.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */

package com.iqiyi.qigsaw.buildtool.gradle

import org.gradle.api.Plugin
import org.gradle.api.Project

abstract class QigsawPlugin implements Plugin<Project> {

    public static final String QIGSAW_BUILD = "QIGSAW_BUILD"

    public static final String QIGSAW = "qigsaw"

    public static final String ASSEMBLE = "Assemble"

    public static final String INSTALL = "Install"

    public static final String QIGSAW_ASSEMBLE_TASK_PREFIX = QIGSAW + ASSEMBLE

    public static final String QIGSAW_INSTALL_TASK_PREFIX = QIGSAW + INSTALL

    static boolean isQigsawBuild(Project project) {
        List<String> startTaskNames = project.gradle.startParameter.taskNames
        for (String taskName : startTaskNames) {
            if (taskName.contains(QIGSAW_ASSEMBLE_TASK_PREFIX) || taskName.contains(QIGSAW_INSTALL_TASK_PREFIX)) {
                return true
            }
        }
        if (project.hasProperty(QIGSAW_BUILD) || System.getenv().containsKey(QIGSAW_BUILD)
                || System.properties.containsKey(QIGSAW_BUILD)) {
            return true
        }
        return false
    }
}
